@@ -1,12 +1,10 @@
 package Catalyst::Action::Serialize::JSON;
-
+$Catalyst::Action::Serialize::JSON::VERSION = '1.17';
 use Moose;
 use namespace::autoclean;
 
 extends 'Catalyst::Action';
-use JSON ();
-
-our $VERSION = '1.14'; # VERSION
+use JSON::MaybeXS qw(JSON);
 
 has encoder => (
    is => 'ro',
